@@ -17,8 +17,23 @@
 #' head(boot_samples)
 #' @export
 parbootstrap <- function(qp, bootstrap = 'parametric', B = 10) {
+  if (qp$pariniset) {
+    if (is.atomic(parini)) {
+      parini <- qp$par
+      pariniset <- FALSE
+    }
+    else{
+      parini <- qp$parini
+      pariniset <- TRUE
+    }
+  }
+  else {
+    parini <- qp$par
+    pariniset <- FALSE
+  }
+
   qp$averages %>% do(one_bootstrap(., qp$x, qp$k, qp$n,
                   qp$psyfunguesslapses, qp$funname, qp$guess, qp$lapses,
-                  qp$parini, qp$pariniset, qp$optimization, bootstrap, B,
+                  parini, pariniset, qp$optimization, bootstrap, B,
                   qp$groups, qp$ypred))
 }
